@@ -97,7 +97,7 @@ canada_raw = '''\
     417.266680178544	    961.765709811429	    6.87000000000262	    469.647234439539'''
 
 canada = np.array(canada_raw.split(), float).reshape(-1,4)
-k=2;
+k=2
 resarch2 = dia.acorr_lm((canada[:,k]-canada[:,k].mean())**2, maxlag=2, autolag=None, store=1)
 print(resarch2)
 resarch5 = dia.acorr_lm(canada[:,k]**2, maxlag=12, autolag=None, store=1)
