@@ -25,7 +25,7 @@ from __future__ import print_function
 import numpy as np
 from numpy.testing import assert_almost_equal
 
-from statsmodels.regression.linear_model import OLS, WLS, GLS
+from statsmodels.regression.linear_model import OLS
 from statsmodels.regression.feasible_gls import GLSHet, GLSHet2
 
 examples = ['ex1']
