@@ -2,18 +2,16 @@
 
 from __future__ import print_function
 import numpy as np
+import matplotlib.pyplot as plt
 #import statsmodels.linear_model.regression as smreg
 
 from scipy import special
 
 import statsmodels.api as sm
 from statsmodels.datasets.macrodata import data
-dta = data.load()
+dta = data.load(as_pandas=False)
 gdp = np.log(dta.data['realgdp'])
 
-from numpy import polynomial
-from scipy import special
-
 
 maxorder = 20
 polybase = special.chebyt
@@ -28,7 +26,6 @@ fitted = [sm.OLS(gdp, exog[:, :maxr]).fit().fittedvalues for maxr in
 
 print((np.corrcoef(exog[:,1:6], rowvar=0)*10000).astype(int))
 
-import matplotlib.pyplot as plt
 
 plt.figure()
 plt.plot(gdp, 'o')
