@@ -5,7 +5,7 @@ import statsmodels.api as sm
 from statsmodels.tsa.api import VAR
 
 # some example data
-mdata = sm.datasets.macrodata.load().data
+mdata = sm.datasets.macrodata.load(as_pandas=False).data
 mdata = mdata[['realgdp','realcons','realinv']]
 names = mdata.dtype.names
 data = mdata.view((float,3))
@@ -41,6 +41,6 @@ fc_out = np.array([VAR(data[:t]).fit(2).forecast(data[t-20:t], h)[-1]
 print(fc_out - data[nobs_all-6:nobs_all])  #out-of-sample forecast error
 print(fc_out - res.fittedvalues[-6:])
 
-import matplotlib.pyplot as plt
+#import matplotlib.pyplot as plt
 res.plot_forecast(20)
 #plt.show()
