@@ -10,8 +10,8 @@ root = '../statsmodels'
 
 print('base, dnames, len(fnames), n_py')
 for base, dnames, fnames in os.walk(root):
-    if not '__init__.py' in fnames:
-        #I have some empty directories when I switch git branches
+    if '__init__.py' not in fnames:
+        # I have some empty directories when I switch git branches
         if (len(dnames) + len(fnames)) != 0:
             n_py = len([f for f in fnames if f[-3:] == '.py'])
             if n_py > 0:
